/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayIcon from '@clayui/icon';
import {ReactDOMServer} from '@liferay/frontend-js-react-web';
import classNames from 'classnames';
import Proptypes from 'prop-types';
import React from 'react';

import {getDataRendererById} from '../utils/dataRenderers';
import {getSchemaString} from '../utils/index';
import DefaultRenderer from './DefaultRenderer';

function TooltipTableRow({
	contentRenderer,
	divider,
	highlighted,
	itemData,
	label,
	value,
	...options
}) {
	let DataRenderer = DefaultRenderer;

	if (contentRenderer) {
		DataRenderer = getDataRendererById(contentRenderer);
	}

	return (
		<tr
			className={classNames(
				divider && 'with-divider',
				highlighted && 'highlighted'
			)}
		>
			<td className="pr-3 table-column-text-start">{label}</td>

			<td className="table-column-text-end text-right">
				<DataRenderer
					itemData={itemData}
					options={options}
					value={value}
				/>
			</td>
		</tr>
	);
}

function TooltipSummaryRenderer({itemData, options, value}) {
	if (!value || !options.details?.rowsDefinitions) {
		return null;
	}

	const tooltipTableRows = options.details.rowsDefinitions.reduce(
		(rowsData, rowDefinition) => {
			const value = getSchemaString(
				itemData,
				rowDefinition.valueFieldKey
			);

			if (value) {
				rowsData.push({
					...rowDefinition,
					value,
				});
			}

			return rowsData;
		},
		[]
	);

	return (
		<>
			{value}
			{!!tooltipTableRows.length && (
				<span
					className="fds-tooltip-summary"
					data-title-set-as-html
					data-tooltip-delay="0"
					title={ReactDOMServer.renderToString(
						<table className="tooltip-table">
							<tbody>
								{tooltipTableRows.map((rowData) => (
									<TooltipTableRow
										key={rowData.label}
										{...rowData}
									/>
								))}
							</tbody>
						</table>
					)}
				>
					<ClayIcon symbol="info-circle" />
				</span>
			)}
		</>
	);
}

TooltipSummaryRenderer.propTypes = {
	options: Proptypes.shape({
		rowsDefinitions: Proptypes.arrayOf(
			Proptypes.shape({
				label: Proptypes.string,
				valueFieldKey: Proptypes.arrayOf(
					Proptypes.oneOfType([Proptypes.string, Proptypes.number])
				),
			})
		),
	}),
	value: Proptypes.oneOfType([Proptypes.string, Proptypes.number]),
};

export default TooltipSummaryRenderer;
