/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import ClayDropDown from '@clayui/drop-down';
import classNames from 'classnames';
import PropTypes from 'prop-types';
import React, {useContext, useState} from 'react';

import FrontendDataSetContext from '../../../FrontendDataSetContext';

function getOdataString() {
	return `test ne 4`;
}

function TestFilter({id, inputText, selectedData}) {
	const {setFilter} = useContext(FrontendDataSetContext);

	const [value, setValue] = useState(selectedData);

	return (
		<ClayDropDown.Caption>
			<div className="form-group">
				<div className="input-group">
					<div
						className={classNames('input-group-item', {
							'input-group-prepend': inputText,
						})}
					>
						<input
							className="form-control"
							onChange={(event) => setValue(event.target.value)}
							type="text"
							value={value || ''}
						/>
					</div>

					<div className="input-group-append input-group-item input-group-item-shrink">
						<span className="input-group-text">
							{Liferay.Language.get('test')}
						</span>
					</div>
				</div>

				<div className="mt-3">
					<ClayButton
						disabled={value === selectedData}
						onClick={() =>
							setFilter(
								id,
								value,
								value,
								getOdataString(value, id)
							)
						}
						small
					>
						{selectedData
							? Liferay.Language.get('edit-filter')
							: Liferay.Language.get('add-filter')}
					</ClayButton>
				</div>
			</div>
		</ClayDropDown.Caption>
	);
}

TestFilter.propTypes = {
	id: PropTypes.string.isRequired,
	inputText: PropTypes.string,
	value: PropTypes.string,
};

export default TestFilter;
