/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

export const ACTION_UPDATE_ACTIVE_VIEW = 'ACTION_UPDATE_ACTIVE_VIEW';
export const ACTION_UPDATE_VIEW_COMPONENT = 'ACTION_UPDATE_VIEW_COMPONENT';
export const ACTION_UPDATE_VISIBLE_FIELD_NAMES =
	'ACTION_UPDATE_VISIBLE_FIELD_NAMES';

export function updateActiveView(activeViewName) {
	return {
		type: ACTION_UPDATE_ACTIVE_VIEW,
		value: activeViewName,
	};
}

export function updateViewComponent(name, component) {
	return {
		type: ACTION_UPDATE_VIEW_COMPONENT,
		value: {component, name},
	};
}

export function updateVisibleFieldNames(visibleFieldNames) {
	return {
		type: ACTION_UPDATE_VISIBLE_FIELD_NAMES,
		value: visibleFieldNames,
	};
}

export function viewsReducer(state, {type, value}) {
	const {activeView, views} = state;

	if (type === ACTION_UPDATE_ACTIVE_VIEW) {
		return {
			...state,
			activeView: views.find(({name}) => name === value),
		};
	}
	else if (type === ACTION_UPDATE_VIEW_COMPONENT) {
		const {component, name} = value;

		return {
			...state,
			activeView:
				name === activeView?.name
					? {
							...activeView,
							component,
					  }
					: activeView,
			views: views.map((view) =>
				view.name === name
					? {
							...view,
							component,
					  }
					: view
			),
		};
	}
	else if (type === ACTION_UPDATE_VISIBLE_FIELD_NAMES) {
		return {
			...state,
			visibleFieldNames: value,
		};
	}

	return state;
}
